package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.SysPlatformMenu;
import com.ruoyi.system.service.ISysPlatformMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 平台和菜单关联Controller
 * 
 * @author usky
 * @date 2022-04-29
 */
@RestController
@RequestMapping("/platformMenu")
public class SysPlatformMenuController extends BaseController
{
    @Autowired
    private ISysPlatformMenuService sysPlatformMenuService;

    /**
     * 查询平台和菜单关联列表
     */
    @RequiresPermissions("system:menu:list")
    @GetMapping("/list")
    public TableDataInfo list(SysPlatformMenu sysPlatformMenu)
    {
        startPage();
        List<SysPlatformMenu> list = sysPlatformMenuService.selectSysPlatformMenuList(sysPlatformMenu);
        return getDataTable(list);
    }

    /**
     * 导出平台和菜单关联列表
     */
    @RequiresPermissions("system:menu:export")
    @Log(title = "平台和菜单关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysPlatformMenu sysPlatformMenu)
    {
        List<SysPlatformMenu> list = sysPlatformMenuService.selectSysPlatformMenuList(sysPlatformMenu);
        ExcelUtil<SysPlatformMenu> util = new ExcelUtil<SysPlatformMenu>(SysPlatformMenu.class);
        util.exportExcel(response, list, "平台和菜单关联数据");
    }

    /**
     * 获取平台和菜单关联详细信息
     */
    @RequiresPermissions("system:menu:query")
    @GetMapping(value = "/{platformId}")
    public AjaxResult getInfo(@PathVariable("platformId") Long platformId)
    {
        return AjaxResult.success(sysPlatformMenuService.selectSysPlatformMenuByPlatformId(platformId));
    }

    /**
     * 新增平台和菜单关联
     */
    @RequiresPermissions("system:menu:add")
    @Log(title = "平台和菜单关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysPlatformMenu sysPlatformMenu)
    {
        return toAjax(sysPlatformMenuService.insertSysPlatformMenu(sysPlatformMenu));
    }

    /**
     * 修改平台和菜单关联
     */
    @RequiresPermissions("system:menu:edit")
    @Log(title = "平台和菜单关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysPlatformMenu sysPlatformMenu)
    {
        return toAjax(sysPlatformMenuService.updateSysPlatformMenu(sysPlatformMenu));
    }

    /**
     * 删除平台和菜单关联
     */
    @RequiresPermissions("system:menu:remove")
    @Log(title = "平台和菜单关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{platformIds}")
    public AjaxResult remove(@PathVariable Long[] platformIds)
    {
        return toAjax(sysPlatformMenuService.deleteSysPlatformMenuByPlatformIds(platformIds));
    }
}
