package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.SysTenantMenu;
import com.ruoyi.system.service.ISysTenantMenuService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 租户和菜单关联Controller
 * 
 * @author usky
 * @date 2022-04-29
 */
@RestController
@RequestMapping("/tenantMenu")
public class SysTenantMenuController extends BaseController
{
    @Autowired
    private ISysTenantMenuService sysTenantMenuService;

    /**
     * 查询租户和菜单关联列表
     */
    @RequiresPermissions("system:menu:list")
    @GetMapping("/list")
    public TableDataInfo list(SysTenantMenu sysTenantMenu)
    {
        startPage();
        List<SysTenantMenu> list = sysTenantMenuService.selectSysTenantMenuList(sysTenantMenu);
        return getDataTable(list);
    }

    /**
     * 导出租户和菜单关联列表
     */
    @RequiresPermissions("system:menu:export")
    @Log(title = "租户和菜单关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysTenantMenu sysTenantMenu)
    {
        List<SysTenantMenu> list = sysTenantMenuService.selectSysTenantMenuList(sysTenantMenu);
        ExcelUtil<SysTenantMenu> util = new ExcelUtil<SysTenantMenu>(SysTenantMenu.class);
        util.exportExcel(response, list, "租户和菜单关联数据");
    }

    /**
     * 获取租户和菜单关联详细信息
     */
    @RequiresPermissions("system:menu:query")
    @GetMapping(value = "/{tenantId}")
    public AjaxResult getInfo(@PathVariable("tenantId") Long tenantId)
    {
        return AjaxResult.success(sysTenantMenuService.selectSysTenantMenuByTenantId(tenantId));
    }

    /**
     * 新增租户和菜单关联
     */
    @RequiresPermissions("system:menu:add")
    @Log(title = "租户和菜单关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysTenantMenu sysTenantMenu)
    {
        return toAjax(sysTenantMenuService.insertSysTenantMenu(sysTenantMenu));
    }

    /**
     * 修改租户和菜单关联
     */
    @RequiresPermissions("system:menu:edit")
    @Log(title = "租户和菜单关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysTenantMenu sysTenantMenu)
    {
        return toAjax(sysTenantMenuService.updateSysTenantMenu(sysTenantMenu));
    }

    /**
     * 删除租户和菜单关联
     */
    @RequiresPermissions("system:menu:remove")
    @Log(title = "租户和菜单关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{tenantIds}")
    public AjaxResult remove(@PathVariable Long[] tenantIds)
    {
        return toAjax(sysTenantMenuService.deleteSysTenantMenuByTenantIds(tenantIds));
    }
}
