package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.system.domain.SysTenantMenu;
import com.ruoyi.system.mapper.SysTenantMenuMapper;
import com.ruoyi.system.service.ISysTenantMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 租户和菜单关联Service业务层处理
 * 
 * @author usky
 * @date 2022-04-29
 */
@Service
public class SysTenantMenuServiceImpl implements ISysTenantMenuService
{
    @Autowired
    private SysTenantMenuMapper sysTenantMenuMapper;

    /**
     * 查询租户和菜单关联
     * 
     * @param tenantId 租户和菜单关联主键
     * @return 租户和菜单关联
     */
    @Override
    public SysTenantMenu selectSysTenantMenuByTenantId(Long tenantId)
    {
        return sysTenantMenuMapper.selectSysTenantMenuByTenantId(tenantId);
    }

    /**
     * 查询租户和菜单关联列表
     * 
     * @param sysTenantMenu 租户和菜单关联
     * @return 租户和菜单关联
     */
    @Override
    public List<SysTenantMenu> selectSysTenantMenuList(SysTenantMenu sysTenantMenu)
    {
        return sysTenantMenuMapper.selectSysTenantMenuList(sysTenantMenu);
    }

    /**
     * 新增租户和菜单关联
     * 
     * @param sysTenantMenu 租户和菜单关联
     * @return 结果
     */
    @Override
    public int insertSysTenantMenu(SysTenantMenu sysTenantMenu)
    {
        return sysTenantMenuMapper.insertSysTenantMenu(sysTenantMenu);
    }

    /**
     * 修改租户和菜单关联
     * 
     * @param sysTenantMenu 租户和菜单关联
     * @return 结果
     */
    @Override
    public int updateSysTenantMenu(SysTenantMenu sysTenantMenu)
    {
        return sysTenantMenuMapper.updateSysTenantMenu(sysTenantMenu);
    }

    /**
     * 批量删除租户和菜单关联
     * 
     * @param tenantIds 需要删除的租户和菜单关联主键
     * @return 结果
     */
    @Override
    public int deleteSysTenantMenuByTenantIds(Long[] tenantIds)
    {
        return sysTenantMenuMapper.deleteSysTenantMenuByTenantIds(tenantIds);
    }

    /**
     * 删除租户和菜单关联信息
     * 
     * @param tenantId 租户和菜单关联主键
     * @return 结果
     */
    @Override
    public int deleteSysTenantMenuByTenantId(Long tenantId)
    {
        return sysTenantMenuMapper.deleteSysTenantMenuByTenantId(tenantId);
    }
}
